containertools.split_container_at_index_and_fracture_crossing_spanners
======================================================================

.. autofunction:: abjad.tools.containertools.split_container_at_index_and_fracture_crossing_spanners.split_container_at_index_and_fracture_crossing_spanners
